<!--suppress HtmlDeprecatedAttribute -->
<p align="center">
  <img
    width="200px" height="200px"
    src="https://raw.githubusercontent.com/astronomer/orbiter/main/docs/orbiter.svg"
    alt="Logo of Spaceship Orbiting a Planet"
  />
</p>
<p align="center">
  <b>Astronomer Orbiter</b> can land legacy workloads safely down in a new home on Apache Airflow!
</p>


## What is it?
`orbiter` is a framework and CLI that runs on your workstation and converts workflow definitions from other tools to Airflow Projects.

[Read more at the official documentation!](https://astronomer.github.io/orbiter)

# Artwork
Orbiter logo [by Ivan Colic](https://thenounproject.com/Ivanisawesome/) used with permission
from [The Noun Project](https://thenounproject.com/icon/lunar-orbiter-196219/)
under [Creative Commons](https://creativecommons.org/licenses/by/3.0/us/legalcode).
